@@ -9,7 +9,7 @@ use PYX::Parser;
 use PYX::Utils qw(encode);
 use Tags::Output::Raw;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -19,18 +19,25 @@ sub new {
 	# Input encoding.
 	$self->{'input_encoding'} = 'utf-8';
 
+	# Input 'Tags' item callback.
+	$self->{'input_tags_item_callback'} = undef;
+
 	# Tags object.
-	$self->{'tags'} = Tags::Output::Raw->new(
-		'output_handler' => \*STDOUT,
-	);
+	$self->{'tags'} = undef;
 
 	# Process params.
 	set_params($self, @params);
 
-	# Check for Tags::Output object.
-	if (! $self->{'tags'}
-		|| ! $self->{'tags'}->isa('Tags::Output')) {
+	if (! defined $self->{'tags'}) {
+		$self->{'tags'} = Tags::Output::Raw->new(
+			'input_tags_item_callback'
+				=> $self->{'input_tags_item_callback'},
+			'output_handler' => \*STDOUT,
+		);
+	}
 
+	# Check for Tags::Output object.
+	if (! $self->{'tags'}->isa('Tags::Output')) {
 		err "Bad 'Tags::Output::*' object.";
 	}
 
@@ -169,6 +176,12 @@ Constructor.
  Input encoding.
  Default value is 'utf-8'.
 
+=item * C<input_tags_item_callback>
+
+ Input 'Tags' item callback.
+ This callback is for Tags::Output::* constructor parameter 'input_tags_item_callback'.
+ Default value is undef.
+
 =item * C<tags>
 
  Tags object.
@@ -286,6 +299,40 @@ Constructor.
  # Output:
  # <element>data</element>
 
+=head1 EXAMPLE3
+
+ use strict;
+ use warnings;
+
+ use PYX::SGML::Tags;
+ use Tags::Output::Indent;
+
+ # Input.
+ my $pyx = <<'END';
+ (element
+ -data
+ )element
+ END
+
+ # Object.
+ my $obj = PYX::SGML::Tags->new(
+         'input_tags_item_callback' => sub {
+                 my $tags_ar = shift;
+                 print '[ '.$tags_ar->[0].' ]'."\n";
+                 return;
+         },
+ );
+
+ # Process.
+ $obj->parse($pyx);
+ print "\n";
+
+ # Output:
+ # [ b ]
+ # [ d ]
+ # [ e ]
+ # <element>data</element>
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -322,6 +369,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
